'''
Tests against remindme's migration handler
'''

import unittest
import migrations


class Test_Migrations(unittest.TestCase):
    '''Tests against the Migrations handler.'''

    def test_detect_versions(self):
        pass
